mergeStrategy property

MergeStrategy mergeStrategy
final

Which strategy should the inference engine use when JSON array contains multiple objects of different types.

Defaults to MergeStrategy.mergeNonMatchingObjects.

See MergeStrategy for more information about how the inference engine combines different types into one type.

Implementation

final MergeStrategy mergeStrategy;