JsonVisitor<T, A> class abstract

Implementers

Constructors

JsonVisitor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
visit(dynamic json, A argument) → T
visitJsonArray(List json, A argument) → T
visitJsonBoolean(bool json, A argument) → T
visitJsonInteger(int json, A argument) → T
visitJsonNull(dynamic json, A argument) → T
visitJsonNumber(num json, A argument) → T
visitJsonObject(Map<String, dynamic> json, A argument) → T
visitJsonString(String json, A argument) → T

Operators

operator ==(Object other) bool
The equality operator.
inherited