InferFromJsonFile class
Properties
-
file
→ String
-
Relative path to file from which the
json_serializable compatible class
should be inferred.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
mergeStrategy
→ MergeStrategy
-
Which strategy should the inference engine use when JSON array contains
multiple objects of different types.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited